==> alfresco-repository-23.7.0.10-sources.jar: org/alfresco/repo/security/person/HomeSpaceNodeRef.java <==
/*
 * #%L
 * Alfresco Repository
 * %%
 * Copyright (C) 2005 - 2016 Alfresco Software Limited
 * %%
 * This file is part of the Alfresco software. 
 * If the software was purchased under a paid Alfresco license, the terms of 
 * the paid license agreement will prevail.  Otherwise, the software is 
 * provided under the following open source license terms:
 * 
 * Alfresco is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Alfresco is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with Alfresco. If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */
package org.alfresco.repo.security.person;

import org.alfresco.service.cmr.repository.NodeRef;

/**
 * A ref to a home folder 
 * - the node ref
 * - a simple status as to how it was obtained 
 * 
 * @author Andy Hind
 */
public class HomeSpaceNodeRef
{
    public enum Status{VALID, REFERENCED, CREATED};
    
    private NodeRef nodeRef;

    private Status status;
    
    public HomeSpaceNodeRef(NodeRef nodeRef, Status status)
    {
        this.nodeRef = nodeRef;
        this.status = status;
    }

    NodeRef getNodeRef()
    {
        return nodeRef;
    }

    Status getStatus()
    {
        return status;
    }
    
    
}

==> alfresco-repository-26.1.0.14-sources.jar: org/alfresco/repo/security/person/HomeSpaceNodeRef.java <==
/*
 * #%L
 * Alfresco Repository
 * %%
 * Copyright (C) 2005 - 2016 Alfresco Software Limited
 * %%
 * This file is part of the Alfresco software. 
 * If the software was purchased under a paid Alfresco license, the terms of 
 * the paid license agreement will prevail.  Otherwise, the software is 
 * provided under the following open source license terms:
 * 
 * Alfresco is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Alfresco is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with Alfresco. If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */
package org.alfresco.repo.security.person;

import org.alfresco.service.cmr.repository.NodeRef;

/**
 * A ref to a home folder - the node ref - a simple status as to how it was obtained
 * 
 * @author Andy Hind
 */
public class HomeSpaceNodeRef
{
    public enum Status
    {
        VALID, REFERENCED, CREATED
    };

    private NodeRef nodeRef;

    private Status status;

    public HomeSpaceNodeRef(NodeRef nodeRef, Status status)
    {
        this.nodeRef = nodeRef;
        this.status = status;
    }

    NodeRef getNodeRef()
    {
        return nodeRef;
    }

    Status getStatus()
    {
        return status;
    }

}
